#!/usr/bin/env python
# coding=utf-8
# Stan 2013-04-24

from tkpip.tkpip import main
main()
